// Docu : http://wiki.moxiecode.com/index.php/TinyMCE:Create_plugin/3.x#Creating_your_own_plugins

(function() {
	// Load plugin specific language pack
	tinymce.PluginManager.requireLangPack('flickrSlideshow');
	
	tinymce.create('tinymce.plugins.flickrSlideshow', {
		/**
		 * Initializes the plugin, this will be executed after the plugin has been created.
		 * This call is done before the editor instance has finished it's initialization so use the onInit event
		 * of the editor instance to intercept that event.
		 *
		 * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
		 * @param {string} url Absolute URL to where the plugin is located.
		 */
		init : function(ed, url) {
			// Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand('mceExample');

			ed.addCommand('mceflickrSlideshow', function() {
				ed.windowManager.open({
					file : url + '/window.php',
					width : 425 + ed.getLang('flickrSlideshow.delta_width', 0),
					height : 610 + ed.getLang('flickrSlideshow.delta_height', 0),
					inline : 1
				}, {
					plugin_url : url // Plugin absolute URL
				});
			});

			// Register example button
			ed.addButton('flickrSlideshow', {
				title : 'Flickr Slideshow',
				cmd : 'mceflickrSlideshow',
				image : url + '/flickrSlideshow.gif'
			});

		},

		/**
		 * Returns information about the plugin as a name/value array.
		 * The current keys are longname, author, authorurl, infourl and version.
		 *
		 * @return {Object} Name/value array containing information about the plugin.
		 */
		getInfo : function() {
			return {
					longname  : 'Flickr Slideshow',
					author 	  : 'Shaun Choo',
					authorurl : 'http://www.fireforeffect.net/',
					infourl   : 'http://www.fireforeffect.net/',
					version   : "0.2"
			};
		}
	});

	// Register plugin
	tinymce.PluginManager.add('flickrSlideshow', tinymce.plugins.flickrSlideshow);
})();


